Learn R Programming

uncmbb (version 0.2.2)

mbb_season_result: Get season's win/loss summary for all match types.

Description

Get season's win/loss summary for all match types.

Usage

mbb_season_result(df)

Arguments

df

Input data frame containing a team's historical match data that are included in uncmbb package.

Value

A data frame containing number of games, wins, losses, win

Examples

Run this code
# NOT RUN {
mbb_season_result(unc)
# }

Run the code above in your browser using DataLab