powered by
Get season's win/loss summary for all match types.
mbb_season_result(df)
Input data frame containing a team's historical match data that are included in uncmbb package.
A data frame containing number of games, wins, losses, win
# NOT RUN { mbb_season_result(unc) # }
Run the code above in your browser using DataLab